// --------------------------------------------------------
// Code generated by Papyrus C++
// --------------------------------------------------------

#ifndef DDICORE_40_PIM_DATATYPES_STRUCTUREDDATATYPES_ADDRESS_H
#define DDICORE_40_PIM_DATATYPES_STRUCTUREDDATATYPES_ADDRESS_H

/************************************************************
 Address class header
 ************************************************************/

#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/Pkg_StructuredDataTypes.h"

#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/DateRange.h"
#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/ExternalControlledVocabularyEntry.h"
#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/ObjectName.h"
#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/SpatialPoint.h"
#include "PrimitiveTypes/Pkg_PrimitiveTypes.h"

namespace DDICore_40_PIM {
namespace DataTypes {
namespace StructuredDataTypes {

/************************************************************/
/**
 * Definition
 * ============
 * Location address identifying each part of the address as separate elements, identifying the type of address, the level of privacy associated with the release of the address, and a flag to identify the preferred address for contact.
 * 
 * Examples
 * ==========
 * For example:
 * 1.  OFFICE, ABS HOUSE, 45 Benjamin Way, Belconnen, Canberra, ACT, 2617, AU
 * 2.  OFFICE, Institute of Education, 20 Bedford Way, London, WC1H 0AL, UK
 * 
 * Explanatory notes
 * ===================
 * 
 * 
 * Synonyms
 * ==========
 * 
 * 
 * DDI 3.2 mapping
 * =================
 * a:AddressType
 * 
 * RDF mapping
 * =============
 * 
 * 
 * GSIM mapping
 * ==============
 */
class Address {
public:

	/**
	 * City, place, or local area used as part of an address.
	 */
	::PrimitiveTypes::String cityPlaceLocal;

	/**
	 * Country of the location
	 */
	ExternalControlledVocabularyEntry countryCode;

	/**
	 * Clarifies when the identification information is accurate.
	 */
	DateRange effectiveDates;

	/**
	 * Geographic coordinates corresponding to the address.
	 */
	SpatialPoint geographicPoint;

	/**
	 * Set to "true" if this is the preferred location for contacting the organization or individual.
	 */
	::PrimitiveTypes::Boolean isPreferred;

	/**
	 * Number and street including office or suite number. May use multiple lines.
	 */
	::PrimitiveTypes::String line[];

	/**
	 * Name of the location if applicable.
	 */
	ObjectName locationName;

	/**
	 * Postal or ZIP Code
	 */
	::PrimitiveTypes::String postalCode;

	/**
	 * Specify the level privacy for the address as public, restricted, or private. Supports the use of an external controlled vocabulary
	 */
	ExternalControlledVocabularyEntry privacy;

	/**
	 * The region covered by the agent at this address
	 */
	ExternalControlledVocabularyEntry regionalCoverage;

	/**
	 * A major subnational division such as a state or province used to identify a major region within an address.
	 */
	::PrimitiveTypes::String stateProvince;

	/**
	 * Time zone of the location expressed as code.
	 */
	ExternalControlledVocabularyEntry timeZone;

	/**
	 * Indicates address type (i.e. home, office, mailing, etc.)
	 */
	ExternalControlledVocabularyEntry typeOfAddress;

	/**
	 * The type or purpose of the location (i.e. regional office, distribution center, home)
	 */
	ExternalControlledVocabularyEntry typeOfLocation;

};
/************************************************************/
/* External declarations (package visibility)               */
/************************************************************/

/* Inline functions                                         */

} // of namespace StructuredDataTypes
} // of namespace DataTypes
} // of namespace DDICore_40_PIM

/************************************************************
 End of Address class header
 ************************************************************/

#endif
